# Sierra

![pyramid logo](https://github.com/BrainStormYourWayIn/pyramid/blob/main/logo.jpg)

A lightweight Python framework for building and Integrating Web Applications.

**NOTE**: This project is currently under heavy development. Please watch/star this repository for further updates on development.

________________________________

## Installation

### Method 1: Download ZIP file

**To download the zip file:** click on the `download` button and then click on the `Download ZIP` button. The zip file will get downloaded in the downloads folder.

**To unzip the zip file:** open the zipped folder, then drag the file or folder from the zipped folder to a new location. To unzip all the contents of the zipped folder, press and hold (or right-click) the folder, select `Extract All`.

### Method 2: Clone repository

To clone the repository, type:

`gh repo clone BrainStormYourWayIn/sierra`

in your terminal/shell.

________________________________

## Under development

The documentation will be coming soon.

**Upcoming:**

- Integration with [Flask](https://palletsprojects.com/p/flask/)
- Official support for [brython over JS](https://brython.info)

________________________________

## Copyright License Used

Copyright (c) 2008-2011, AQR Capital Management, LLC, Lambda Foundry, Inc. and PyData Development Team
All rights reserved.

Copyright (c) 2011-2020, Open source contributors.
